@@ -1,7 +1,7 @@
 package Perinci::Sub::To::CLIDocData;
 
-our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2016-09-26'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -204,12 +204,18 @@ sub gen_cli_doc_data_from_meta {
             }
             $pos++;
             next unless defined($arg);
+            if ($arg_spec->{greedy}) {
+                # try to find the singular form
+                $arg = $arg_spec->{'x.name.singular'}
+                    if $arg_spec->{'x.name.is_plural'} &&
+                    defined $arg_spec->{'x.name.singular'};
+            }
             if ($arg_spec->{req}) {
                 push @args, "<$arg>";
             } else {
                 push @args, "[$arg]";
             }
-            $args[-1] .= "..." if $arg_spec->{greedy};
+            $args[-1] .= " ..." if $arg_spec->{greedy};
             delete $args_prop{$arg};
         }
         unshift @args, "[options]" if keys(%args_prop) || keys(%$common_opts); # XXX translatable?
@@ -479,7 +485,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.24 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-12-17.
+This document describes version 0.25 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2016-09-26.
 
 =head1 SYNOPSIS
 
@@ -628,12 +634,6 @@ Sample result:
 For a more complete sample, see function metadata for C<demo_cli_opts> in
 L<Perinci::Examples::CLI>.
 
-=head1 SEE ALSO
-
-L<Perinci::CmdLine>, L<Perinci::CmdLine::Lite>
-
-L<Pod::Weaver::Plugin::Rinci>
-
 =head1 FUNCTIONS
 
 
@@ -713,13 +713,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci::CmdLine>, L<Perinci::CmdLine::Lite>
+
+L<Pod::Weaver::Plugin::Rinci>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
